@@ -273,23 +273,23 @@ void Titraqform::setupActions(void)
     m_pPasteact->setWhatsThis(kszPastetext);
 
     // Add data row action
-    m_pAddrowact = new QAction(trUtf8("Add Row"), Rowaddiset, trUtf8("&Add row"), Key_Insert, this, "Addrow");
+    m_pAddrowact = new QAction(trUtf8("Add Entry"), Rowaddiset, trUtf8("&Add entry"), Key_Insert, this, "Addentry");
     if (m_pAddrowact == NULL)   // Sanity check
-        throw Genexcept("Main window add row action creation failed.");
+        throw Genexcept("Main window add entry action creation failed.");
     connect(m_pAddrowact, SIGNAL(activated()), this, SLOT(addEntry()));
     const char *kszAddrowtext = "<p><img source=\"rowadd\"> "
-                                "Click this button to add a <em>new row</em>. "
+                                "Click this button to add a <em>new entry</em>. "
                                 "You can also select the <b>Add</b> command "
                                 "from the <b>Edit</b> menu.</p>";
     m_pAddrowact->setWhatsThis(kszAddrowtext);
 
     // Delete data row action
-    m_pDelrowact = new QAction(trUtf8("Delete Row"), Rowdeliset, trUtf8("&Delete row"), Key_Delete, this, "Delrow");
+    m_pDelrowact = new QAction(trUtf8("Delete Entry"), Rowdeliset, trUtf8("&Delete entry"), Key_Delete, this, "Delentry");
     if (m_pDelrowact == NULL)   // Sanity check
-        throw Genexcept("Main window delete row action creation failed.");
+        throw Genexcept("Main window delete entry action creation failed.");
     connect(m_pDelrowact, SIGNAL(activated()), this, SLOT(delEntry()));
     const char *kszDelrowtext = "<p><img source=\"rowdel\"> "
-                                   "Click this button to delete a <em>row</em>. "
+                                   "Click this button to delete a <em>entry</em>. "
                                    "You can also select the <b>Delete</b> command "
                                    "from the <b>Edit</b> menu.</p>";
     m_pDelrowact->setWhatsThis(kszDelrowtext);
@@ -649,7 +649,7 @@ void Titraqform::setupEditlay(void)
     // Whatsthis info for the item status edit
     const char *kszStatustext = "The <em>item status</em> shows a green "
                                 "symbol for valid entries, a yellow symbol "
-                                "to warn, and a red symbol for flawed entries.";
+                                "for warning, and a red symbol for flawed entries.";
     QWhatsThis::add(m_pStatusedit, kszStatustext);
     QToolTip::add(m_pStatusedit, trUtf8("Status Indicator"));
     m_pEditlayout->addWidget(m_pStatusedit);  // Finally add the item status edit
