@@ -32,6 +32,7 @@
 // Qt general headers
 #include <qregexp.h>            // Portable regular expressions
 #include <qdatetime.h>
+#include <qmessagebox.h>
 
 // User interface
 #include "as_gui.h"             // Main classes
@@ -73,8 +74,8 @@ void Titraqform::loadAccounts(QTextStream &Tstream)
 
     // Eat lines until reading the start accounts token
     while (!Line.startsWith(trUtf8("%!AS-ACCOUNTS")) && !Tstream.atEnd()) {
-        Line = trUtf8(""); // Empty line for later inspection
-        Line = Tstream.readLine(); // Get a new line to examine
+        Line = QString("");         // Empty line for later inspection
+        Line = Tstream.readLine();  // Get a new line to examine
     }
 
     // Strip out extra line feeds in stream
@@ -82,7 +83,7 @@ void Titraqform::loadAccounts(QTextStream &Tstream)
         Tstream.skipWhiteSpace();       // Strip and get
         Line = Tstream.readLine();      // the new line
         if (Line.at(0) == QChar('#'))   // Remove comments
-            Line = trUtf8("");
+            Line = QString("");
     }
 
     // Set the accounts choices by linewise reading from the input
@@ -99,12 +100,12 @@ void Titraqform::loadAccounts(QTextStream &Tstream)
             *m_pTaskentries << Temp;        // to internal account bank
         }
 
-        Line = trUtf8(""); // Clear line for next round
+        Line = QString(""); // Clear line for next round
         while (Line.isEmpty() && !Tstream.atEnd()) {
             Tstream.skipWhiteSpace();       // Strip and get
             Line = Tstream.readLine();      // the new line
             if (Line.at(0) == QChar('#'))   // Remove comments
-                Line = trUtf8("");
+                Line = QString("");
         }
     }
 }
@@ -150,7 +151,41 @@ void Titraqform::loadData(QTextStream &Tstream)
         Tstream.skipWhiteSpace();       // Strip and get
         Line = Tstream.readLine();      // the new line
         if (Line.at(0) == QChar('#'))   // Remove comments
-            Line = trUtf8("");
+            Line = QString("");
+    }
+
+    // Ensure that the right data version pattern precedes the data
+    QString Datapattern = QString(TITRAQ_DATAPATTERN);
+    if (!Line.startsWith(Datapattern)) { // Incompatible data format
+        QMessageBox Problema(TITRAQ_APPTITLE,
+            TITRAQ_NOPATTERNFOUND + QString(TITRAQ_DATAPATTERN) + TITRAQ_WASNOTFOUNDIN,
+            QMessageBox::Critical, QMessageBox::Ok | QMessageBox::Escape,
+            QMessageBox::NoButton, QMessageBox::NoButton);
+        Problema.exec(); // Give the user the bad news
+        throw Genexcept(TITRAQ_INVALIDDATA);
+    }
+    else if (Line.section(Datapattern, 1).section('.', 0, 0).toInt() != TITRAQ_DATAVERSIONMAJ) {
+        QMessageBox Problema(TITRAQ_APPTITLE, TITRAQ_BADVERSIONMAJ,
+            QMessageBox::Warning, QMessageBox::Ok | QMessageBox::Escape,
+            QMessageBox::NoButton, QMessageBox::NoButton);
+        Problema.exec(); // Give the user the bad news
+        throw Genexcept(TITRAQ_INCOMPATDATA);
+    }
+    else if (Line.section(Datapattern, 1).section('.', 1, 1).toInt() > TITRAQ_DATAVERSIONMIN) {
+        QMessageBox Problema(TITRAQ_APPTITLE, TITRAQ_BADVERSIONMIN,
+            QMessageBox::Warning, QMessageBox::Ok | QMessageBox::Escape,
+            QMessageBox::NoButton, QMessageBox::NoButton);
+        Problema.exec(); // Give the user the bad news
+        throw Genexcept(TITRAQ_INCOMPATDATA);
+    }
+
+    // Strip out extra line feeds after reading the data symbol
+    Line = QString("");                 // Reset our line
+    while (Line.isEmpty() && !Tstream.atEnd()) {
+        Tstream.skipWhiteSpace();       // Strip and get
+        Line = Tstream.readLine();      // the new line
+        if (Line.at(0) == QChar('#'))   // Remove comments
+            Line = QString("");
     }
 
 //    // Going into data churning, so prepare date and time parsing and conversion
@@ -271,13 +306,13 @@ void Titraqform::loadData(QTextStream &Tstream)
         }
 
         nIter++;            // The big increment
-        Line = trUtf8("");  // Clear line for next round
+        Line = QString(""); // Clear line for next round
 
         while (Line.isEmpty() && !Tstream.atEnd()) {    // Strip and get
             Tstream.skipWhiteSpace();                   // Remove white
             Line = Tstream.readLine();                  // the new line
             if (Line.at(0) == QChar('#'))               // Remove comments
-                Line = trUtf8("");
+                Line = QString("");
         }
     }
 
@@ -329,8 +364,9 @@ void Titraqform::saveData(QTextStream &Tstream)
     QString Strsearch;                              // String to strip search
     QRegExp Stripper("\\s*$");                      // Pattern to strip off
 
-    // Optimize viewing by repainting cells only once after processing
-    m_pMaintable->setUpdatesEnabled(false);
+    // Start by prepending the AS data format version symbol
+    Tstream << TITRAQ_DATAPATTERN << TITRAQ_DATAVERSIONMAJ
+            << QChar('.') << TITRAQ_DATAVERSIONMIN << endl;
 
     // Linewise save from the main table date, time, account, and others
     for (int nIter = 0; nIter < nRows; nIter++) {
@@ -386,8 +422,6 @@ void Titraqform::saveData(QTextStream &Tstream)
 
         Tstream << endl;                                            // Append a newline
     }
-
-    m_pMaintable->setUpdatesEnabled(true); // Update and repaint
 }
 
 //
