@@ -70,11 +70,11 @@ Titraqform::Titraqform(QWidget *pParent, const char *kszName, WFlags Flags) :
     // Postsetup manipulations
     m_pMaintable->setDirty(false);
     if (!kszName)
-        setName(trUtf8("Titraqform"));
+        setName(trUtf8("ASGuiapp"));
     resize(m_pPrefs->getNumber(TITRAQ_PREFFRAMEWIDTH, TITRAQ_DEFFRAMEWIDTH),
         m_pPrefs->getNumber(TITRAQ_PREFFRAMEHEIGHT, TITRAQ_DEFFRAMEHEIGHT));
     connect(qApp, SIGNAL(aboutToQuit()), this, SLOT(savePrefs()));
-    setCaption("OSSP Titraq");
+    setCaption("AS Accounting System");
 
     // Rehydrate main window layout and doc positions
     QString Laystring = m_pPrefs->getString(TITRAQ_PREFFRAMELAY, NULL); // FIXME: Handle first case better
