@@ -313,7 +313,7 @@ void Titraqform::refreshDisplay(void)
 //
 void Titraqform::newDoc(void)
 {
-    int nResult = 0;
+    int nResult = 0; // Holds return value from save first messagebox
 
     // Check modification state of current data
     if (m_pMaintable->isDirty()) {
@@ -323,24 +323,28 @@ void Titraqform::newDoc(void)
 
         switch (nResult) {
         case 0: // First button selected, so save first
-            this->saveFile();               // Save changes first
+            this->saveFile();   // Save changes first
             break;
         case 1: // Second button selected, so don't save
             break;
         case 2: // Third button selected, so return sofort
         default:
+            m_pStatbar->message(trUtf8("New aborted"), 4000);
             return;
             break;
         }
     }
-    // Fall through to implicit new doc code
-    this->enableIface(true);            // Enable the interface
-    m_pMaintable->setNumRows(0);        // Remove all data in table
-    this->setCaption(trUtf8("No file name"));
-    m_pStatbar->message(trUtf8("New document"), 4000);
-    this->setFilename(QString(""));
-    this->addEntry(1);                  // Default new op adds a row
-    m_pMaintable->setDirty(false);      // Start out clean
+
+    if (!m_pMaintable->isDirty() || nResult == 1) { // Check modification state
+        // Fall through to implicit new doc code
+        this->setCaption(trUtf8("No file name"));
+        m_pStatbar->message(trUtf8("New document"), 4000);
+        this->enableIface(true);            // Enable the interface
+        m_pMaintable->setNumRows(0);        // Remove all data in table
+        this->setFilename("");               // Signal a closed doc state
+        this->addEntry(1);                  // Default new op adds a row
+        m_pMaintable->setDirty(false);      // Start out clean
+    }
 }
 
 //
@@ -348,71 +352,71 @@ void Titraqform::newDoc(void)
 //
 void Titraqform::openDoc(void)
 {
-    int nResult = 0;    // Holds return value from save first messagebox
+    int nResult = 0; // Holds return value from save first messagebox
 
-    // Make sure we correctly get the name of the default file to open
-    QString Openas = m_pPrefs->getString(TITRAQ_PREFASFILE, TITRAQ_DEFASFILE);
-    if (Openas.startsWith(TITRAQ_HOMEDIRTOK))
-        Openas = QDir::homeDirPath() + Openas.remove(0, QString(TITRAQ_HOMEDIRTOK).length() - 1);
+//
+// This block will guide the user to saving the contents of the timesheet
+// before losing them in an open operation. The question and dialog box will
+// not be raised if no open timesheet exists or if it was just serialized.
+//
+    if (m_pMaintable->isDirty()) { // Check modification state
+        nResult = QMessageBox::information(this, trUtf8(TITRAQ_APPTITLE),
+                  trUtf8(TITRAQ_SAVEFIRST), trUtf8("&Save"),
+                  trUtf8("&Discard"), trUtf8("Cancel"), 0, 2);
 
-    QString Filestring = QFileDialog::getOpenFileName(Openas, trUtf8("Accounting Data (*.as);;Text files (*.txt);;All Files (*)"), this, trUtf8("ChooserDialog"), trUtf8("Choose a file to open"), NULL, false);
-
-    if (!Filestring.isEmpty()) {
-        QFile Filetemp(Filestring); // File to load
-        // Check modification state of current data
-        if (m_pMaintable->isDirty()) {
-            nResult = QMessageBox::information(this, trUtf8(TITRAQ_APPTITLE),
-                      trUtf8(TITRAQ_SAVEFIRST), trUtf8("&Save"),
-                      trUtf8("&Discard"), trUtf8("Cancel"), 0, 2);
-
-            switch (nResult) {
-            case 0: // Save first
-                this->saveFile();               // Save changes first
-                setFilename(Filestring);        // Set the new file name
-                m_pMaintable->setNumRows(0);    // Clear out old data
-                try {
-                    loadData(Filetemp);         // Pass to helper method
-                }
-                catch (Genexcept& Genex) {
-                    Genex.reportErr();
-                    return;
-                }
-                break;
-            case 1: // Don't save first but do load
-                setFilename(Filestring);        // Set the new file name
-                m_pMaintable->setNumRows(0);    // Clear out old data
-                try {
-                    loadData(Filetemp);         // Pass to helper method
-                }
-                catch (Genexcept& Genex) {
-                    Genex.reportErr();
-                    return;
-                }
-                break;
-            case 2: // Don't do a load timesheet
-            default:
-                break;
-            }
+        switch (nResult) {
+        case 0: // Save first
+            this->saveFile(); // Save changes first
+            break;
+        case 1: // Don't save first but do load
+            break;
+        case 2: // Don't do a load timesheet
+        default:
+            m_pStatbar->message(trUtf8("Loading aborted"), 4000);
+            return;
+            break;
         }
-        else {
+    }
+
+//
+// This block ensures that conditions of first block logic were met if
+// applicable. If so, the user gives a file name to open or cancels the
+// operation. The corresponding file will be opened, and if this is
+// unsuccessful then the post state is exactly the same as the pre state.
+//
+    if (!m_pMaintable->isDirty() || nResult == 1) { // Check modification state
+        // Make sure we correctly get the name of the default file to open
+        QString Openas = m_pPrefs->getString(TITRAQ_PREFASFILE, TITRAQ_DEFASFILE);
+        if (Openas.startsWith(TITRAQ_HOMEDIRTOK))
+            Openas = QDir::homeDirPath() + Openas.remove(0, QString(TITRAQ_HOMEDIRTOK).length() - 1);
+
+        // This dialog asks which file the user wants to open
+        QString Filestring = QFileDialog::getOpenFileName(Openas,
+            trUtf8("Accounting Data (*.as);;Text files (*.txt);;All Files (*)"),
+            this, trUtf8("ChooserDialog"), trUtf8("Choose a file to open"), NULL, false);
+
+        // We might have a filename to work on, so do something with it
+        if (!Filestring.isEmpty()) {
             setFilename(Filestring);            // Set the new file name
             m_pMaintable->setNumRows(0);        // Clear out old data
+            m_pMaintable->setDirty(false);      // Reset dirty flag
+            QFile Filetemp(Filestring);         // File to load
             try {
                 loadData(Filetemp);             // Pass to helper method
+                this->setCaption(Filestring);   // Caption in the titlebar
+                m_pStatbar->message(trUtf8("Loaded document ") + Filestring, 4000);
+                this->enableIface(true);        // Turn on the lights
             }
-            catch (Genexcept& Genex) {
+            catch (Genexcept& Genex) { // Crap, we failed
+                m_pStatbar->message(trUtf8("Loading failed"), 4000);
+                this->setOpen(false);
                 Genex.reportErr();
                 return;
             }
         }
-
-        // Fall through to implicit open code
-        this->setCaption(Filestring);
-        m_pStatbar->message(trUtf8("Loaded document ") + Filestring, 4000);
-        this->enableIface(true);    // Turn on the lights
+        else // An empty filename returning from the file dialog means cancel
+            m_pStatbar->message(trUtf8("Loading aborted"), 4000);
     }
-    else
-        m_pStatbar->message(trUtf8("Loading aborted"), 4000);
 }
 
 //
@@ -1594,8 +1598,8 @@ void Titraqform::helpContents(void)
 //
 void Titraqform::aboutTitraq(void)
 {
-    QMessageBox *pCwmsg = new QMessageBox("OSSP titraq",
-        QObject::trUtf8("OSSP titraq is a time and task-based\n"
+    QMessageBox *pCwmsg = new QMessageBox("AS Accounting System",
+        QObject::trUtf8("As-gui is a time and task-based\n"
                "accounting system that acts as both a\n"
                "work-like punch card and time tracker.\n"
                "Development of titraq is sponsored by\n"
@@ -1613,7 +1617,7 @@ void Titraqform::aboutTitraq(void)
 //
 void Titraqform::aboutOSSP(void)
 {
-    QMessageBox *pOsspmsg = new QMessageBox("OSSP titraq",
+    QMessageBox *pOsspmsg = new QMessageBox("AS Accounting System",
         QObject::trUtf8("The open source software project (OSSP) is\n"
                "a collective effort aimed at implementing\n"
                "high-quality Unix software components,\n"
@@ -1633,5 +1637,5 @@ void Titraqform::aboutOSSP(void)
 //
 void Titraqform::aboutQt(void)
 {
-    QMessageBox::aboutQt(this, "OSSP titraq");
+    QMessageBox::aboutQt(this, "AS Accounting System");
 }
